@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from future.builtins import int, range, str
 
 from datetime import date, datetime
 from os.path import join, split
@@ -146,7 +148,7 @@ class FormForForm(forms.ModelForm):
                           "help_text": field.help_text}
             if field.required and not field.help_text:
                 field_args["help_text"] = _("required")
-            arg_names = field_class.__init__.im_func.func_code.co_varnames
+            arg_names = field_class.__init__.__code__.co_varnames
             if "max_length" in arg_names:
                 field_args["max_length"] = settings.FORMS_FIELD_MAX_LENGTH
             if "choices" in arg_names:
@@ -182,7 +184,7 @@ class FormForForm(forms.ModelForm):
 
             if field.field_type == fields.DOB:
                 _now = datetime.now()
-                years = range(_now.year, _now.year - 120, -1)
+                years = list(range(_now.year, _now.year - 120, -1))
                 self.fields[field_key].widget.years = years
 
             # Add identifying type attr to the field for styling.
@@ -253,7 +255,7 @@ class EntriesForm(forms.Form):
         self.form = form
         self.request = request
         self.form_fields = form.fields.all()
-        self.entry_time_name = unicode(FormEntry._meta.get_field(
+        self.entry_time_name = str(FormEntry._meta.get_field(
             "entry_time").verbose_name).encode("utf-8")
         super(EntriesForm, self).__init__(*args, **kwargs)
         for field in self.form_fields:
